searchData={"items":[{"type":"module","doc":"# Poison\n\n[![Build Status](https://img.shields.io/github/actions/workflow/status/devinus/poison/ci.yml)](https://github.com/devinus/poison/actions/workflows/ci.yml)\n[![Coverage Status](https://img.shields.io/coverallsCoverage/github/devinus/poison)](https://coveralls.io/github/devinus/poison?branch=master))\n[![Hex.pm Version](https://img.shields.io/hexpm/v/poison)](https://hex.pm/packages/poison)\n[![Hex.pm Download Total](https://img.shields.io/hexpm/dt/poison)](https://hex.pm/packages/poison)\n[![Hex.pm Dependents](https://img.shields.io/librariesio/dependents/hex/poison)](https://hex.pm/packages/poison)\n\nPoison is a new JSON library for Elixir focusing on wicked-fast **speed**\nwithout sacrificing **simplicity**, **completeness**, or **correctness**.\n\nPoison takes several approaches to be the fastest JSON library for Elixir.\n\nPoison uses extensive [sub binary matching][1], a **hand-rolled parser** using\nseveral techniques that are [known to benefit BeamAsm][2] for JIT compilation,\n[IO list][3] encoding and **single-pass** decoding.\n\nPoison benchmarks sometimes puts Poison's performance close to `jiffy` and\nusually faster than other Erlang/Elixir libraries.\n\nPoison fully conforms to [RFC 8259][4], [ECMA 404][5], and fully passes the\n[JSONTestSuite][6].","title":"Poison","ref":"Poison.html"},{"type":"module","doc":"First, add Poison to your `mix.exs` dependencies:\n\n```elixir\ndef deps do\n  [{:poison, \"~> 6.0\"}]\nend\n```\n\nThen, update your dependencies:\n\n```sh\nmix deps.get\n```","title":"Installation - Poison","ref":"Poison.html#module-installation"},{"type":"module","doc":"```elixir\nPoison.encode!(%{\"age\" => 27, \"name\" => \"Devin Torres\"})\n#=> \"{\\\"name\\\":\\\"Devin Torres\\\",\\\"age\\\":27}\"\n\nPoison.decode!(~s({\"name\": \"Devin Torres\", \"age\": 27}))\n#=> %{\"age\" => 27, \"name\" => \"Devin Torres\"}\n\ndefmodule Person do\n  @derive [Poison.Encoder]\n  defstruct [:name, :age]\nend\n\nPoison.encode!(%Person{name: \"Devin Torres\", age: 27})\n#=> \"{\\\"name\\\":\\\"Devin Torres\\\",\\\"age\\\":27}\"\n\nPoison.decode!(~s({\"name\": \"Devin Torres\", \"age\": 27}), as: %Person{})\n#=> %Person{name: \"Devin Torres\", age: 27}\n\nPoison.decode!(~s({\"people\": [{\"name\": \"Devin Torres\", \"age\": 27}]}),\n  as: %{\"people\" => [%Person{}]})\n#=> %{\"people\" => [%Person{age: 27, name: \"Devin Torres\"}]}\n```\n\nEvery component of Poison (encoder, decoder, and parser) are all usable on\ntheir own without buying into other functionality. For example, if you were\ninterested purely in the speed of parsing JSON without a decoding step, you\ncould simply call `Poison.Parser.parse`.","title":"Usage - Poison","ref":"Poison.html#module-usage"},{"type":"module","doc":"```iex\niex> Poison.Parser.parse!(~s({\"name\": \"Devin Torres\", \"age\": 27}), %{})\n%{\"name\" => \"Devin Torres\", \"age\" => 27}\niex> Poison.Parser.parse!(~s({\"name\": \"Devin Torres\", \"age\": 27}), %{keys: :atoms!})\n%{name: \"Devin Torres\", age: 27}\n```\n\nNote that `keys: :atoms!` reuses existing atoms, i.e. if `:name` was not\nallocated before the call, you will encounter an `argument error` message.\n\nYou can use the `keys: :atoms` variant to make sure all atoms are created as\nneeded. However, unless you absolutely know what you're doing, do **not** do\nit. Atoms are not garbage-collected, see\n[Erlang Efficiency Guide](http://www.erlang.org/doc/efficiency_guide/commoncaveats.html)\nfor more info:\n\n> Atoms are not garbage-collected. Once an atom is created, it will never be\n> removed. The emulator will terminate if the limit for the number of atoms\n> (1048576 by default) is reached.","title":"Parser - Poison","ref":"Poison.html#module-parser"},{"type":"module","doc":"```iex\niex> Poison.Encoder.encode([1, 2, 3], %{}) |> IO.iodata_to_binary\n\"[1,2,3]\"\n```\n\nAnything implementing the Encoder protocol is expected to return an\n[IO list][7] to be embedded within any other Encoder's implementation and\npassable to any IO subsystem without conversion.\n\n```elixir\ndefimpl Poison.Encoder, for: Person do\n  def encode(%{name: name, age: age}, options) do\n    Poison.Encoder.BitString.encode(\"#{name} (#{age})\", options)\n  end\nend\n```\n\nFor maximum performance, make sure you `@derive [Poison.Encoder]` for any\nstruct you plan on encoding.","title":"Encoder - Poison","ref":"Poison.html#module-encoder"},{"type":"module","doc":"When deriving structs for encoding, it is possible to select or exclude\nspecific attributes. This is achieved by deriving `Poison.Encoder` with the\n`:only` or `:except` options set:\n\n```elixir\ndefmodule PersonOnlyName do\n  @derive {Poison.Encoder, only: [:name]}\n  defstruct [:name, :age]\nend\n\ndefmodule PersonWithoutName do\n  @derive {Poison.Encoder, except: [:name]}\n  defstruct [:name, :age]\nend\n```\n\nIn case both `:only` and `:except` keys are defined, the `:except` option is\nignored.","title":"Encoding only some attributes - Poison","ref":"Poison.html#module-encoding-only-some-attributes"},{"type":"module","doc":"According to [RFC 8259][4] keys in a JSON object should be unique. This is\nenforced and resolved in different ways in other libraries. In the Ruby JSON\nlibrary for example, the output generated from encoding a hash with a duplicate\nkey (say one is a string, the other an atom) will include both keys. When\nparsing JSON of this type, Chromium will override all previous values with the\nfinal one.\n\nPoison will generate JSON with duplicate keys if you attempt to encode a map\nwith atom and string keys whose encoded names would clash. If you'd like to\nensure that your generated JSON doesn't have this issue, you can pass the\n`strict_keys: true` option when encoding. This will force the encoding to fail.\n\n_Note:_ Validating keys can cause a small performance hit.\n\n```iex\niex> Poison.encode!(%{:foo => \"foo1\", \"foo\" => \"foo2\"}, strict_keys: true)\n** (Poison.EncodeError) duplicate key found: :foo\n```","title":"Key Validation - Poison","ref":"Poison.html#module-key-validation"},{"type":"module","doc":"```sh\nMIX_ENV=bench mix run bench/run.exs\n```","title":"Benchmarking - Poison","ref":"Poison.html#module-benchmarking"},{"type":"module","doc":"As of 2024-06-06:\n\n- Amazon EC2 c6i.2xlarge instance running Ubuntu Server 22.04:","title":"Current Benchmarks - Poison","ref":"Poison.html#module-current-benchmarks"},{"type":"module","doc":"Poison is released under the [public-domain-equivalent][8] [0BSD][9] license.\n\n[1]: https://erlang.org/euc/07/papers/1700Gustafsson.pdf\n[2]: https://erlang.org/documentation/doc-12.0-rc1/erts-12.0/doc/html/BeamAsm.html\n[3]: https://jlouisramblings.blogspot.com/2013/07/problematic-traits-in-erlang.html\n[4]: https://datatracker.ietf.org/doc/html/rfc8259\n[5]: https://ecma-international.org/wp-content/uploads/ECMA-404_2nd_edition_december_2017.pdf\n[6]: https://github.com/nst/JSONTestSuite\n[7]: https://prog21.dadgum.com/70.html\n[8]: https://en.wikipedia.org/wiki/Public-domain-equivalent_license\n[9]: https://opensource.org/licenses/0BSD","title":"License - Poison","ref":"Poison.html#module-license"},{"type":"function","doc":"Decode JSON to a value.\n\n    iex> Poison.decode(\"[1,2,3]\")\n    {:ok, [1, 2, 3]}\n\n    iex> Poison.decode(\"[\")\n    {:error, %Poison.ParseError{data: \"[\", skip: 1, value: nil}}","title":"Poison.decode/2","ref":"Poison.html#decode/2"},{"type":"function","doc":"Decode JSON to a value. Raises an exception on error.\n\n    iex> Poison.decode!(\"[1,2,3]\")\n    [1, 2, 3]\n\n    iex> Poison.decode!(\"[\")\n    ** (Poison.ParseError) unexpected end of input at position 1","title":"Poison.decode!/2","ref":"Poison.html#decode!/2"},{"type":"function","doc":"Encode a value to JSON.\n\n    iex> Poison.encode([1, 2, 3])\n    {:ok, \"[1,2,3]\"}\n\n    iex> Poison.encode({})\n    {:error, %Poison.EncodeError{message: nil, value: {}}}","title":"Poison.encode/2","ref":"Poison.html#encode/2"},{"type":"function","doc":"Encode a value to JSON. Raises an exception on error.\n\n    iex> Poison.encode!([1, 2, 3])\n    \"[1,2,3]\"\n\n    iex> Poison.encode!({})\n    ** (Poison.EncodeError) unable to encode value: {}","title":"Poison.encode!/2","ref":"Poison.html#encode!/2"},{"type":"function","doc":"Encode a value to JSON IO data.\n\n    iex> Poison.encode_to_iodata([1, 2, 3])\n    {:ok, [91, [\"1\", 44, \"2\", 44, \"3\"], 93]}\n\n    iex> Poison.encode_to_iodata({})\n    {:error, %Poison.EncodeError{message: nil, value: {}}}","title":"Poison.encode_to_iodata/2","ref":"Poison.html#encode_to_iodata/2"},{"type":"function","doc":"Encode a value to JSON IO data. Raises an exception on error.\n\n    iex> Poison.encode_to_iodata!([1, 2, 3])\n    [91, [\"1\", 44, \"2\", 44, \"3\"], 93]\n\n    iex> Poison.encode_to_iodata!({})\n    ** (Poison.EncodeError) unable to encode value: {}","title":"Poison.encode_to_iodata!/2","ref":"Poison.html#encode_to_iodata!/2"},{"type":"protocol","doc":"","title":"Poison.Decoder","ref":"Poison.Decoder.html"},{"type":"function","doc":"","title":"Poison.Decoder.decode/2","ref":"Poison.Decoder.html#decode/2"},{"type":"type","doc":"","title":"Poison.Decoder.as/0","ref":"Poison.Decoder.html#t:as/0"},{"type":"type","doc":"","title":"Poison.Decoder.decimal/0","ref":"Poison.Decoder.html#t:decimal/0"},{"type":"type","doc":"","title":"Poison.Decoder.keys/0","ref":"Poison.Decoder.html#t:keys/0"},{"type":"type","doc":"","title":"Poison.Decoder.option/0","ref":"Poison.Decoder.html#t:option/0"},{"type":"type","doc":"","title":"Poison.Decoder.options/0","ref":"Poison.Decoder.html#t:options/0"},{"type":"type","doc":"All the types that implement this protocol.","title":"Poison.Decoder.t/0","ref":"Poison.Decoder.html#t:t/0"},{"type":"protocol","doc":"","title":"Poison.Encoder","ref":"Poison.Encoder.html"},{"type":"function","doc":"","title":"Poison.Encoder.encode/2","ref":"Poison.Encoder.html#encode/2"},{"type":"type","doc":"","title":"Poison.Encoder.escape/0","ref":"Poison.Encoder.html#t:escape/0"},{"type":"type","doc":"","title":"Poison.Encoder.indent/0","ref":"Poison.Encoder.html#t:indent/0"},{"type":"type","doc":"","title":"Poison.Encoder.offset/0","ref":"Poison.Encoder.html#t:offset/0"},{"type":"type","doc":"","title":"Poison.Encoder.option/0","ref":"Poison.Encoder.html#t:option/0"},{"type":"type","doc":"","title":"Poison.Encoder.options/0","ref":"Poison.Encoder.html#t:options/0"},{"type":"type","doc":"","title":"Poison.Encoder.pretty/0","ref":"Poison.Encoder.html#t:pretty/0"},{"type":"type","doc":"","title":"Poison.Encoder.strict_keys/0","ref":"Poison.Encoder.html#t:strict_keys/0"},{"type":"type","doc":"All the types that implement this protocol.","title":"Poison.Encoder.t/0","ref":"Poison.Encoder.html#t:t/0"},{"type":"module","doc":"An RFC 8259 and ECMA 404 conforming JSON parser.\n\nSee: https://datatracker.ietf.org/doc/html/rfc8259\nSee: https://ecma-international.org/wp-content/uploads/ECMA-404_2nd_edition_december_2017.pdf","title":"Poison.Parser","ref":"Poison.Parser.html"},{"type":"function","doc":"","title":"Poison.Parser.parse!/2","ref":"Poison.Parser.html#parse!/2"},{"type":"type","doc":"","title":"Poison.Parser.scalar/0","ref":"Poison.Parser.html#t:scalar/0"},{"type":"type","doc":"","title":"Poison.Parser.t/0","ref":"Poison.Parser.html#t:t/0"},{"type":"exception","doc":"","title":"Poison.DecodeError","ref":"Poison.DecodeError.html"},{"type":"type","doc":"","title":"Poison.DecodeError.t/0","ref":"Poison.DecodeError.html#t:t/0"},{"type":"exception","doc":"","title":"Poison.EncodeError","ref":"Poison.EncodeError.html"},{"type":"type","doc":"","title":"Poison.EncodeError.t/0","ref":"Poison.EncodeError.html#t:t/0"},{"type":"exception","doc":"","title":"Poison.MissingDependencyError","ref":"Poison.MissingDependencyError.html"},{"type":"function","doc":"","title":"Poison.MissingDependencyError.message/1","ref":"Poison.MissingDependencyError.html#message/1"},{"type":"type","doc":"","title":"Poison.MissingDependencyError.t/0","ref":"Poison.MissingDependencyError.html#t:t/0"},{"type":"exception","doc":"","title":"Poison.ParseError","ref":"Poison.ParseError.html"},{"type":"function","doc":"","title":"Poison.ParseError.message/1","ref":"Poison.ParseError.html#message/1"},{"type":"type","doc":"","title":"Poison.ParseError.t/0","ref":"Poison.ParseError.html#t:t/0"},{"type":"extras","doc":"# Poison\n\n[![Build Status](https://img.shields.io/github/actions/workflow/status/devinus/poison/ci.yml)](https://github.com/devinus/poison/actions/workflows/ci.yml)\n[![Coverage Status](https://img.shields.io/coverallsCoverage/github/devinus/poison)](https://coveralls.io/github/devinus/poison?branch=master))\n[![Hex.pm Version](https://img.shields.io/hexpm/v/poison)](https://hex.pm/packages/poison)\n[![Hex.pm Download Total](https://img.shields.io/hexpm/dt/poison)](https://hex.pm/packages/poison)\n[![Hex.pm Dependents](https://img.shields.io/librariesio/dependents/hex/poison)](https://hex.pm/packages/poison)\n\nPoison is a new JSON library for Elixir focusing on wicked-fast **speed**\nwithout sacrificing **simplicity**, **completeness**, or **correctness**.\n\nPoison takes several approaches to be the fastest JSON library for Elixir.\n\nPoison uses extensive [sub binary matching][1], a **hand-rolled parser** using\nseveral techniques that are [known to benefit BeamAsm][2] for JIT compilation,\n[IO list][3] encoding and **single-pass** decoding.\n\nPoison benchmarks sometimes puts Poison's performance close to `jiffy` and\nusually faster than other Erlang/Elixir libraries.\n\nPoison fully conforms to [RFC 8259][4], [ECMA 404][5], and fully passes the\n[JSONTestSuite][6].","title":"Poison","ref":"readme.html"},{"type":"extras","doc":"First, add Poison to your `mix.exs` dependencies:\n\n```elixir\ndef deps do\n  [{:poison, \"~> 6.0\"}]\nend\n```\n\nThen, update your dependencies:\n\n```sh\nmix deps.get\n```","title":"Installation - Poison","ref":"readme.html#installation"},{"type":"extras","doc":"```elixir\nPoison.encode!(%{\"age\" => 27, \"name\" => \"Devin Torres\"})\n#=> \"{\\\"name\\\":\\\"Devin Torres\\\",\\\"age\\\":27}\"\n\nPoison.decode!(~s({\"name\": \"Devin Torres\", \"age\": 27}))\n#=> %{\"age\" => 27, \"name\" => \"Devin Torres\"}\n\ndefmodule Person do\n  @derive [Poison.Encoder]\n  defstruct [:name, :age]\nend\n\nPoison.encode!(%Person{name: \"Devin Torres\", age: 27})\n#=> \"{\\\"name\\\":\\\"Devin Torres\\\",\\\"age\\\":27}\"\n\nPoison.decode!(~s({\"name\": \"Devin Torres\", \"age\": 27}), as: %Person{})\n#=> %Person{name: \"Devin Torres\", age: 27}\n\nPoison.decode!(~s({\"people\": [{\"name\": \"Devin Torres\", \"age\": 27}]}),\n  as: %{\"people\" => [%Person{}]})\n#=> %{\"people\" => [%Person{age: 27, name: \"Devin Torres\"}]}\n```\n\nEvery component of Poison (encoder, decoder, and parser) are all usable on\ntheir own without buying into other functionality. For example, if you were\ninterested purely in the speed of parsing JSON without a decoding step, you\ncould simply call `Poison.Parser.parse`.","title":"Usage - Poison","ref":"readme.html#usage"},{"type":"extras","doc":"```iex\niex> Poison.Parser.parse!(~s({\"name\": \"Devin Torres\", \"age\": 27}), %{})\n%{\"name\" => \"Devin Torres\", \"age\" => 27}\niex> Poison.Parser.parse!(~s({\"name\": \"Devin Torres\", \"age\": 27}), %{keys: :atoms!})\n%{name: \"Devin Torres\", age: 27}\n```\n\nNote that `keys: :atoms!` reuses existing atoms, i.e. if `:name` was not\nallocated before the call, you will encounter an `argument error` message.\n\nYou can use the `keys: :atoms` variant to make sure all atoms are created as\nneeded. However, unless you absolutely know what you're doing, do **not** do\nit. Atoms are not garbage-collected, see\n[Erlang Efficiency Guide](http://www.erlang.org/doc/efficiency_guide/commoncaveats.html)\nfor more info:\n\n> Atoms are not garbage-collected. Once an atom is created, it will never be\n> removed. The emulator will terminate if the limit for the number of atoms\n> (1048576 by default) is reached.","title":"Parser - Poison","ref":"readme.html#parser"},{"type":"extras","doc":"```iex\niex> Poison.Encoder.encode([1, 2, 3], %{}) |> IO.iodata_to_binary\n\"[1,2,3]\"\n```\n\nAnything implementing the Encoder protocol is expected to return an\n[IO list][7] to be embedded within any other Encoder's implementation and\npassable to any IO subsystem without conversion.\n\n```elixir\ndefimpl Poison.Encoder, for: Person do\n  def encode(%{name: name, age: age}, options) do\n    Poison.Encoder.BitString.encode(\"#{name} (#{age})\", options)\n  end\nend\n```\n\nFor maximum performance, make sure you `@derive [Poison.Encoder]` for any\nstruct you plan on encoding.","title":"Encoder - Poison","ref":"readme.html#encoder"},{"type":"extras","doc":"When deriving structs for encoding, it is possible to select or exclude\nspecific attributes. This is achieved by deriving `Poison.Encoder` with the\n`:only` or `:except` options set:\n\n```elixir\ndefmodule PersonOnlyName do\n  @derive {Poison.Encoder, only: [:name]}\n  defstruct [:name, :age]\nend\n\ndefmodule PersonWithoutName do\n  @derive {Poison.Encoder, except: [:name]}\n  defstruct [:name, :age]\nend\n```\n\nIn case both `:only` and `:except` keys are defined, the `:except` option is\nignored.","title":"Encoding only some attributes - Poison","ref":"readme.html#encoding-only-some-attributes"},{"type":"extras","doc":"According to [RFC 8259][4] keys in a JSON object should be unique. This is\nenforced and resolved in different ways in other libraries. In the Ruby JSON\nlibrary for example, the output generated from encoding a hash with a duplicate\nkey (say one is a string, the other an atom) will include both keys. When\nparsing JSON of this type, Chromium will override all previous values with the\nfinal one.\n\nPoison will generate JSON with duplicate keys if you attempt to encode a map\nwith atom and string keys whose encoded names would clash. If you'd like to\nensure that your generated JSON doesn't have this issue, you can pass the\n`strict_keys: true` option when encoding. This will force the encoding to fail.\n\n_Note:_ Validating keys can cause a small performance hit.\n\n```iex\niex> Poison.encode!(%{:foo => \"foo1\", \"foo\" => \"foo2\"}, strict_keys: true)\n** (Poison.EncodeError) duplicate key found: :foo\n```","title":"Key Validation - Poison","ref":"readme.html#key-validation"},{"type":"extras","doc":"```sh\nMIX_ENV=bench mix run bench/run.exs\n```","title":"Benchmarking - Poison","ref":"readme.html#benchmarking"},{"type":"extras","doc":"As of 2024-06-06:\n\n- Amazon EC2 c6i.2xlarge instance running Ubuntu Server 22.04:","title":"Current Benchmarks - Poison","ref":"readme.html#current-benchmarks"},{"type":"extras","doc":"Poison is released under the [public-domain-equivalent][8] [0BSD][9] license.\n\n[1]: https://erlang.org/euc/07/papers/1700Gustafsson.pdf\n[2]: https://erlang.org/documentation/doc-12.0-rc1/erts-12.0/doc/html/BeamAsm.html\n[3]: https://jlouisramblings.blogspot.com/2013/07/problematic-traits-in-erlang.html\n[4]: https://datatracker.ietf.org/doc/html/rfc8259\n[5]: https://ecma-international.org/wp-content/uploads/ECMA-404_2nd_edition_december_2017.pdf\n[6]: https://github.com/nst/JSONTestSuite\n[7]: https://prog21.dadgum.com/70.html\n[8]: https://en.wikipedia.org/wiki/Public-domain-equivalent_license\n[9]: https://opensource.org/licenses/0BSD","title":"License - Poison","ref":"readme.html#license"},{"type":"extras","doc":"# Poison Changelog","title":"Changelog","ref":"changelog.html"},{"type":"extras","doc":"","title":"v6.0.0 - Changelog","ref":"changelog.html#v6-0-0"},{"type":"extras","doc":"* Support Erlang 27 and Elixir 1.17\n    [#214](https://github.com/devinus/poison/issues/214)\n    [#222](https://github.com/devinus/poison/issues/222)\n* Reintroduce `Poison.encode_to_iodata!/1` for Phoenix compatibility\n    [#172](https://github.com/devinus/poison/issues/172)\n    [#206](https://github.com/devinus/poison/pull/206)\n* Make [`:html_safe`](`t:Poison.Encoder.escape/0`) encode option follow OWASP\n  recommended HTML escaping\n    [#194](https://github.com/devinus/poison/issues/194)\n* Add `Date.Range` encoding\n* Allow [`:as`](`t:Poison.Decoder.as/0`) decode option to be a function\n    [#207](https://github.com/devinus/poison/pull/207)\n* Add a [CHANGELOG](CHANGELOG.md)\n    [#105](https://github.com/devinus/poison/issues/105)","title":"Features - Changelog","ref":"changelog.html#features"},{"type":"extras","doc":"* Stop double decoding structs\n    [#191](https://github.com/devinus/poison/issues/191)\n* Fix various typespecs\n    [#199](https://github.com/devinus/poison/issues/199)\n* Correctly encode some UTF-8 surrogate pairs\n    [#217](https://github.com/devinus/poison/issues/217)","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* Significantly improve performance\n    ([2024-06-06](https://gist.github.com/devinus/afb351ae45194a6b93b6db9bf2d4c163))","title":"Performance Improvements - Changelog","ref":"changelog.html#performance-improvements"},{"type":"extras","doc":"* Remove deprecated `HashSet` encoding\n* Minimum supported versions are now Erlang 24 and Elixir 1.12","title":"Breaking Changes - Changelog","ref":"changelog.html#breaking-changes"},{"type":"extras","doc":"BSD Zero Clause License\n\nCopyright (C) 2024 Devin Alexander Torres  \n\nPermission to use, copy, modify, and/or distribute this software for any\npurpose with or without fee is hereby granted.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH\nREGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY\nAND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,\nINDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM\nLOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR\nOTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR\nPERFORMANCE OF THIS SOFTWARE.","title":"License","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}